@@ -55,7 +55,7 @@
 
 #define DEFAULT_COMMAND_COMPILE "make"
 #define DEFAULT_COMMAND_BUILD "make"
-#define DEFAULT_COMMAND_BUILD_TARBALL "make tarball"
+#define DEFAULT_COMMAND_BUILD_TARBALL "make dist"
 #define DEFAULT_COMMAND_INSTALL "make install"
 #define DEFAULT_COMMAND_CONFIGURE "./configure"
 #define DEFAULT_COMMAND_GENERATE "./autogen.sh"
@@ -154,7 +154,7 @@ build_indicator_location_set (BuildIndicatorLocation *loc,
 							  IAnjutaEditor *editor,
 							  const gchar *editor_filename)
 {
-	gint line_start, line_end;
+	IAnjutaIterable *line_start, *line_end;
 	
 	if (editor && editor_filename &&
 		IANJUTA_IS_INDICABLE (editor) &&
@@ -162,14 +162,18 @@ build_indicator_location_set (BuildIndicatorLocation *loc,
 		strcmp (editor_filename, loc->filename) == 0)
 	{
 		DEBUG_PRINT ("loc line: %d", loc->line);
-	
+		
 		line_start = ianjuta_editor_get_line_begin_position (editor,
 															 loc->line, NULL);
+		
 		line_end = ianjuta_editor_get_line_end_position (editor,
 														 loc->line, NULL);
 		ianjuta_indicable_set (IANJUTA_INDICABLE (editor),
 							   line_start, line_end, loc->indicator,
 							   NULL);
+		
+		g_object_unref (line_start);
+		g_object_unref (line_end);
 	}
 }
 
@@ -715,6 +719,7 @@ on_build_mesg_parse (IAnjutaMessageView *view, const gchar *line,
 	if (parse_error_line (line, &filename, &lineno))
 	{
 		IAnjutaDocumentManager *docman;
+		gchar *uri;
 		
 		/* Go to file and line number */
 		docman = anjuta_shell_get_interface (context->plugin->shell,
@@ -722,8 +727,13 @@ on_build_mesg_parse (IAnjutaMessageView *view, const gchar *line,
 											 NULL);
 		
 		/* Full path is detected from parse_error_line() */
-		ianjuta_document_manager_goto_file_line_mark(docman, filename, lineno, TRUE, NULL);
+		uri = gnome_vfs_get_uri_from_local_path(filename);
 		g_free(filename);
+		if (uri)
+		{
+			ianjuta_document_manager_goto_file_line_mark(docman, uri, lineno, TRUE, NULL);
+			g_free(uri);
+		}
 	}
 }
 
@@ -745,12 +755,12 @@ on_build_terminated (AnjutaLauncher *launcher,
 		if (status)
 		{
 			ianjuta_message_view_buffer_append (context->message_view,
-									_("Completed... unsuccessful\n"), NULL);
+									_("Completed unsuccessful\n"), NULL);
 		}
 		else
 		{
 			ianjuta_message_view_buffer_append (context->message_view,
-									   _("Completed... successful\n"), NULL);
+									   _("Completed successful\n"), NULL);
 		}
 		ianjuta_message_view_buffer_append (context->message_view, buff1, NULL);
 		g_free (buff1);
@@ -1894,11 +1904,12 @@ on_editor_destroy (IAnjutaEditor *editor, BasicAutotoolsPlugin *ba_plugin)
 }
 
 static void
-on_editor_changed (IAnjutaEditor *editor, gint position, gboolean added,
-				   gint length, gint lines, const gchar *text,
+on_editor_changed (IAnjutaEditor *editor, IAnjutaIterable *position,
+				   gboolean added, gint length, gint lines, const gchar *text,
 				   BasicAutotoolsPlugin *ba_plugin)
 {
-	gint line, begin_pos, end_pos;
+	gint line;
+	IAnjutaIterable *begin_pos, *end_pos;
 	if (g_hash_table_lookup (ba_plugin->editors_created,
 							 editor) == NULL)
 		return;
@@ -1911,9 +1922,11 @@ on_editor_changed (IAnjutaEditor *editor, gint position, gboolean added,
 		ianjuta_indicable_set (IANJUTA_INDICABLE (editor), begin_pos,
 							   end_pos, IANJUTA_INDICABLE_NONE, NULL);
 	}
-	DEBUG_PRINT ("Editor changed: position = %d, added = %d,"
+	DEBUG_PRINT ("Editor changed: line = %d, added = %d,"
 				 " length = %d, lines = %d, text = \'%s\'",
-				 position, added, length, lines, text);
+				 line, added, length, lines, text);
+	g_object_unref (begin_pos);
+	g_object_unref (end_pos);
 }
 
 static void
