@@ -30,9 +30,11 @@
 /*#define DEBUG*/
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-message-manager.h>
-#include <libanjuta/interfaces/ianjuta-cpu-debugger.h>
+#include <libanjuta/interfaces/ianjuta-debugger-register.h>
+#include <libanjuta/interfaces/ianjuta-debugger-memory.h>
+#include <libanjuta/interfaces/ianjuta-debugger-instruction.h>
 #include <libanjuta/interfaces/ianjuta-debugger-breakpoint.h>
-#include <libanjuta/interfaces/ianjuta-variable-debugger.h>
+#include <libanjuta/interfaces/ianjuta-debugger-variable.h>
 
 
 #include <stdarg.h>
@@ -144,6 +146,7 @@ dma_debugger_queue_clear (DmaDebuggerQueue *self)
 	while (g_queue_pop_head(self->queue) != NULL);
 	if (self->last != NULL)
 	{
+		DEBUG_PRINT("clear command %x", dma_command_get_type (self->last));
 		dma_command_free (self->last);
 		self->last = NULL;
 	}
@@ -362,9 +365,6 @@ dma_debugger_queue_complete (DmaDebuggerQueue *self, IAnjutaDebuggerState state)
 {
 	DEBUG_PRINT("debugger_queue_complete %d", state);
 
-	/* Emit new state if necessary */
-	dma_queue_emit_debugger_state (self, state, NULL);
-	
 	if (state != IANJUTA_DEBUGGER_BUSY)
 	{
 		if (self->last != NULL)
@@ -381,6 +381,10 @@ dma_debugger_queue_complete (DmaDebuggerQueue *self, IAnjutaDebuggerState state)
 			dma_command_free (self->last);
 			self->last = NULL;
 		}
+
+	
+		/* Emit new state if necessary */
+		dma_queue_emit_debugger_state (self, state, NULL);
 		
 		/* Send next command */
 		dma_debugger_queue_execute (self);
@@ -392,8 +396,6 @@ dma_debugger_queue_complete (DmaDebuggerQueue *self, IAnjutaDebuggerState state)
 static void
 dma_debugger_queue_execute (DmaDebuggerQueue *self)
 {
-	GError *err = NULL;
-
 	DEBUG_PRINT("debugger_queue_execute");
 
 	/* Check if debugger is connected to a debugger backend */
@@ -412,15 +414,17 @@ dma_debugger_queue_execute (DmaDebuggerQueue *self)
 	while (!g_queue_is_empty(self->queue) && (self->last == NULL))
 	{
 		DmaQueueCommand *cmd;
+		GError *err = NULL;
+		gboolean ok;
 		
 		cmd = (DmaQueueCommand *)g_queue_pop_head(self->queue);
 
 		/* Start command */
 		self->last = cmd;
 		DEBUG_PRINT("run command %x", dma_command_get_type (cmd));
-		dma_command_run (cmd, self->debugger, &err);
+		ok = dma_command_run (cmd, self->debugger, self, &err);
 
-		if (err != NULL)
+		if (!ok || (err != NULL))
 		{
 			/* Something fail */
 			if (dma_command_is_going_to_state (self->last) != IANJUTA_DEBUGGER_BUSY)
@@ -436,12 +440,15 @@ dma_debugger_queue_execute (DmaDebuggerQueue *self)
 			self->last = NULL;
 
 			/* Display error message to user */
-			if (err->message != NULL)
+			if (err != NULL)
 			{
-				anjuta_util_dialog_error (GTK_WINDOW (ANJUTA_PLUGIN (self->plugin)->shell), err->message);
-			}
+				if (err->message != NULL)
+				{
+					anjuta_util_dialog_error (GTK_WINDOW (ANJUTA_PLUGIN (self->plugin)->shell), err->message);
+				}
 			
-			g_error_free (err);
+				g_error_free (err);
+			}
 		}
 	}
 	
@@ -510,10 +517,20 @@ dma_debugger_activate_plugin (DmaDebuggerQueue* self, const gchar *mime_type)
 
 	/* Get list of debugger plugins */
 	plugin_manager = anjuta_shell_get_plugin_manager (ANJUTA_PLUGIN(self->plugin)->shell, NULL);
-	descs = anjuta_plugin_manager_query (plugin_manager,
-					"Anjuta Plugin","Interfaces", "IAnjutaDebugger",
-					"File Loader", "SupportedMimeTypes", mime_type,
-					NULL);
+	if (mime_type == NULL)
+	{
+		/* User has to select the right debugger */
+		descs = anjuta_plugin_manager_query (plugin_manager,
+						"Anjuta Plugin","Interfaces", "IAnjutaDebugger", NULL);
+	}
+	else
+	{
+		/* Propose only debugger supporting correct mime type */
+		descs = anjuta_plugin_manager_query (plugin_manager,
+						"Anjuta Plugin","Interfaces", "IAnjutaDebugger",
+						"File Loader", "SupportedMimeTypes", mime_type,
+						NULL);
+	}
 
 	if (descs == NULL)
 	{
@@ -548,8 +565,12 @@ dma_debugger_activate_plugin (DmaDebuggerQueue* self, const gchar *mime_type)
 		self->debugger = (IAnjutaDebugger *)anjuta_plugin_manager_get_plugin_by_id (plugin_manager, value);
 
 		self->support = 0;
-		/* Check if cpu interface is available */
-		self->support |= IANJUTA_IS_CPU_DEBUGGER(self->debugger) ? HAS_CPU : 0;
+		/* Check if register interface is available */
+		self->support |= IANJUTA_IS_DEBUGGER_REGISTER(self->debugger) ? HAS_REGISTER : 0;
+		/* Check if memory interface is available */
+		self->support |= IANJUTA_IS_DEBUGGER_MEMORY(self->debugger) ? HAS_MEMORY : 0;
+		/* Check if instruction interface is available */
+		self->support |= IANJUTA_IS_DEBUGGER_INSTRUCTION(self->debugger) ? HAS_INSTRUCTION : 0;
 		/* Check if breakpoint interface is available */
 		self->support |= IANJUTA_IS_DEBUGGER_BREAKPOINT(self->debugger) ? HAS_BREAKPOINT : 0;
 		if (IANJUTA_IS_DEBUGGER_BREAKPOINT (self->debugger))
@@ -557,7 +578,7 @@ dma_debugger_activate_plugin (DmaDebuggerQueue* self, const gchar *mime_type)
 			self->support |= ianjuta_debugger_breakpoint_implement (IANJUTA_DEBUGGER_BREAKPOINT (self->debugger), NULL) * HAS_BREAKPOINT * 2;
 		}			
 		/* Check if variable interface is available */
-		self->support |= IANJUTA_IS_VARIABLE_DEBUGGER(self->debugger) ? HAS_VARIABLE : 0;
+		self->support |= IANJUTA_IS_DEBUGGER_VARIABLE(self->debugger) ? HAS_VARIABLE : 0;
 		
 		g_free (value);
 
@@ -631,7 +652,7 @@ on_dma_program_exited (DmaDebuggerQueue *self)
 }
 
 static void
-on_dma_program_moved (DmaDebuggerQueue *self, guint pid, gint tid, guint address, const gchar* src_path, guint line)
+on_dma_program_moved (DmaDebuggerQueue *self, guint pid, gint tid, gulong address, const gchar* src_path, guint line)
 {
 	DEBUG_PRINT ("From debugger: program moved");
 	self->prepend_command++;
@@ -672,6 +693,19 @@ on_dma_sharedlib_event (DmaDebuggerQueue *self)
 /* Public function
  *---------------------------------------------------------------------------*/
 
+/* Command callback will add their commands at the beginning of the queue */
+void
+dma_debugger_queue_command_callback (const gpointer data, gpointer user_data, GError* err)
+{
+	DmaDebuggerQueue *self = (DmaDebuggerQueue *)user_data;
+
+	g_return_if_fail (self->last != NULL);
+	
+	self->prepend_command++;
+	dma_command_callback (self->last, data, err);
+	self->prepend_command--;	
+}
+
 gboolean
 dma_debugger_queue_append (DmaDebuggerQueue *self, DmaQueueCommand *cmd)
 {
