@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -23,11 +23,14 @@
 
 #include "threads.h"
 
+#include "queue.h"
+
 #include <sys/stat.h>
 #include <unistd.h>
 #include <string.h>
 #include <ctype.h>
 #include <gnome.h>
+#include <libgnomevfs/gnome-vfs.h>
 
 /*#define DEBUG*/
 #include <libanjuta/resources.h>
@@ -43,7 +46,7 @@
 struct _DmaThreads
 {
 	DebugManagerPlugin *plugin;
-	IAnjutaDebugger *debugger;
+	DmaDebuggerQueue *debugger;
 
 	/* GUI */
 	GtkWidget *scrolledwindow;
@@ -127,7 +130,7 @@ static void
 on_threads_set_activate (GtkAction *action, gpointer user_data)
 {
 	DmaThreads *self = (DmaThreads *)user_data;
-	guint selected_thread;
+	gint selected_thread;
 	
 	selected_thread = get_current_index (self);
 	
@@ -140,7 +143,7 @@ on_threads_set_activate (GtkAction *action, gpointer user_data)
 		return;
 	
 	/* issue a command to switch active frame to new location */
-	ianjuta_debugger_set_thread (self->debugger, selected_thread, NULL);
+	dma_queue_set_thread (self->debugger, selected_thread);
 }
 
 static void
@@ -153,7 +156,7 @@ on_threads_source_activate (GtkAction *action, gpointer user_data)
 	gchar *uri;
 	guint line;
 	gchar *adr;
-	guint address;
+	gulong address;
 	DmaThreads* self = (DmaThreads*) user_data;		
 
 	view = self->list;
@@ -169,7 +172,7 @@ on_threads_source_activate (GtkAction *action, gpointer user_data)
 						-1);
 
 	address = adr != NULL ? strtoul (adr, NULL, 0) : 0;
-	dma_debug_manager_goto_code (self->plugin, uri, line, address);
+	g_signal_emit_by_name (self->plugin, "location-changed", address, uri, line);
 	g_free (uri);
 	g_free (adr);
 }
@@ -214,11 +217,11 @@ on_info_thread (const IAnjutaDebuggerFrame* frame, gpointer user_data)
 	
 	if (frame == NULL) return;
 	
-	adr = g_strdup_printf ("0x%x", frame->address);
+	adr = g_strdup_printf ("0x%lx", frame->address);
 	
 	if (frame->file)
 	{
-		uri = g_strconcat ("file://", frame->file, NULL);
+		uri = gnome_vfs_get_uri_from_local_path(frame->file);
 		file = strrchr(uri, '/') + 1;
 	}
 	else	
@@ -286,7 +289,8 @@ on_list_thread (const GList *threads, gpointer user_data)
 		else
 			pic = NULL;
 
-		if (frame->address == 0)
+		if ((dma_debugger_queue_is_supported (self->debugger, HAS_MEMORY) && (frame->address == 0))
+			|| (frame->function == NULL))
 		{
 			/* Missing frame address, request more information */
 			GtkTreeRowReference* reference;
@@ -296,11 +300,10 @@ on_list_thread (const GList *threads, gpointer user_data)
 			reference = gtk_tree_row_reference_new (GTK_TREE_MODEL (model), path);
 			gtk_tree_path_free (path);
 			
-			ianjuta_debugger_info_thread (
+			dma_queue_info_thread (
 				self->debugger, frame->thread,
 				(IAnjutaDebuggerCallback)on_info_thread,
-				reference,
-				NULL);
+				reference);
 			
 			gtk_list_store_set(model, &iter, 
 						   	THREAD_ACTIVE_COLUMN, pic,
@@ -309,10 +312,10 @@ on_list_thread (const GList *threads, gpointer user_data)
 		}
 		else
 		{
-			adr = g_strdup_printf ("0x%x", frame->address);
+			adr = g_strdup_printf ("0x%lx", frame->address);
 			if (frame->file)
 			{
-				uri = g_strconcat ("file://", frame->file, NULL);
+				uri = gnome_vfs_get_uri_from_local_path(frame->file);
 				file = strrchr(uri, '/') + 1;
 			}
 			else	
@@ -343,11 +346,10 @@ on_list_thread (const GList *threads, gpointer user_data)
 static void
 dma_threads_update (DmaThreads *self)
 {
-	ianjuta_debugger_list_thread (
+	dma_queue_list_thread (
 			self->debugger,
 			(IAnjutaDebuggerCallback)on_list_thread,
-			self,
-			NULL);
+			self);
 }
 
 /* Actions table
@@ -447,14 +449,18 @@ dma_threads_create_gui(DmaThreads *self)
 	gtk_tree_view_column_set_title (column, _("Function"));
 	gtk_tree_view_append_column (self->list, column);
 	
-	column = gtk_tree_view_column_new ();
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_tree_view_column_pack_start (column, renderer, TRUE);
-	gtk_tree_view_column_add_attribute (column, renderer, "text",
-										THREAD_ADDR_COLUMN);
-	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
-	gtk_tree_view_column_set_title (column, _("Address"));
-	gtk_tree_view_append_column (self->list, column);
+	if (dma_debugger_queue_is_supported (self->debugger, HAS_MEMORY))
+	{
+		/* Display address only if debugger has such concept */
+		column = gtk_tree_view_column_new ();
+		renderer = gtk_cell_renderer_text_new ();
+		gtk_tree_view_column_pack_start (column, renderer, TRUE);
+		gtk_tree_view_column_add_attribute (column, renderer, "text",
+											THREAD_ADDR_COLUMN);
+		gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+		gtk_tree_view_column_set_title (column, _("Address"));
+		gtk_tree_view_append_column (self->list, column);
+	}
 	
 	/* Create popup menu */
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN(self->plugin)->shell, NULL);
@@ -494,31 +500,18 @@ dma_destroy_threads_gui (DmaThreads *self)
 }
 
 static void
-on_program_stopped (DmaThreads *self, guint thread)
+on_program_moved (DmaThreads *self, guint pid, gint thread)
 {
 	self->current_thread = thread;
 	dma_threads_update (self);
 }
 
-static void
-on_debugger_started (DmaThreads *self)
-{
-	dma_threads_create_gui (self);
-}
-
-static void
-on_debugger_stopped (DmaThreads *self)
-{
-	dma_threads_clear (self);
-	dma_destroy_threads_gui (self);
-}
-
 static gboolean
 on_mark_selected_thread (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer user_data)
 {
 	DmaThreads* self = (DmaThreads *)user_data;
 	GdkPixbuf *pic;
-	guint thread;
+	gint thread;
 
 	gtk_tree_model_get (model, iter, THREAD_ACTIVE_COLUMN, &pic, THREAD_ID_COLUMN, &thread, -1);
 	
@@ -547,7 +540,7 @@ on_mark_selected_thread (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *it
 }
 
 static void
-on_frame_changed (DmaThreads *self, guint frame, guint thread)
+on_frame_changed (DmaThreads *self, guint frame, gint thread)
 {
 	if (thread != self->current_thread)
 	{
@@ -560,11 +553,32 @@ on_frame_changed (DmaThreads *self, guint frame, guint thread)
 	}
 }
 
+static void
+on_program_exited (DmaThreads *self)
+{
+	g_signal_handlers_disconnect_by_func (self->plugin, G_CALLBACK (on_program_exited), self);
+	g_signal_handlers_disconnect_by_func (self->plugin, G_CALLBACK (on_program_moved), self);
+	g_signal_handlers_disconnect_by_func (self->plugin, G_CALLBACK (on_frame_changed), self);
+	
+	dma_threads_clear (self);
+	dma_destroy_threads_gui (self);
+}
+
+static void
+on_program_started (DmaThreads *self)
+{
+	dma_threads_create_gui (self);
+	
+	g_signal_connect_swapped (self->plugin, "program-exited", G_CALLBACK (on_program_exited), self);
+	g_signal_connect_swapped (self->plugin, "program-moved", G_CALLBACK (on_program_moved), self);
+	g_signal_connect_swapped (self->plugin, "frame-changed", G_CALLBACK (on_frame_changed), self);
+}
+
 /* Constructor & Destructor
  *---------------------------------------------------------------------------*/
 
 DmaThreads*
-dma_threads_new (IAnjutaDebugger *debugger, DebugManagerPlugin *plugin)
+dma_threads_new (DebugManagerPlugin *plugin)
 {
 	DmaThreads* self;
 	AnjutaUI *ui;
@@ -573,24 +587,18 @@ dma_threads_new (IAnjutaDebugger *debugger, DebugManagerPlugin *plugin)
 	g_return_val_if_fail (self != NULL, NULL);
 
 	self->plugin = plugin;
-	self->debugger = debugger;
-	if (debugger != NULL) g_object_ref (debugger);
+	self->debugger = dma_debug_manager_get_queue (plugin);
 
 	/* Register actions */
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN(self->plugin)->shell, NULL);
-	DEBUG_PRINT("add actions");
 	self->action_group =
 		anjuta_ui_add_action_group_entries (ui, "ActionGroupThread",
 											_("Thread operations"),
 											actions_threads,
 											G_N_ELEMENTS (actions_threads),
 											GETTEXT_PACKAGE, TRUE, self);
-	DEBUG_PRINT("add actions end");
 
-	g_signal_connect_swapped (self->debugger, "debugger-started", G_CALLBACK (on_debugger_started), self);
-	g_signal_connect_swapped (self->debugger, "debugger-stopped", G_CALLBACK (on_debugger_stopped), self);
-	g_signal_connect_swapped (self->debugger, "program-stopped", G_CALLBACK (on_program_stopped), self);
-	g_signal_connect_swapped (self->debugger, "frame-changed", G_CALLBACK (on_frame_changed), self);
+	g_signal_connect_swapped (self->plugin, "program-started", G_CALLBACK (on_program_started), self);
 	
 	return self;
 }
@@ -601,16 +609,9 @@ dma_threads_free (DmaThreads *self)
 	AnjutaUI *ui;
 	
 	g_return_if_fail (self != NULL);
-
+	
 	/* Disconnect from debugger */
-	if (self->debugger != NULL)
-	{	
-		g_signal_handlers_disconnect_by_func (self->debugger, G_CALLBACK (on_debugger_started), self);
-		g_signal_handlers_disconnect_by_func (self->debugger, G_CALLBACK (on_debugger_stopped), self);
-		g_signal_handlers_disconnect_by_func (self->debugger, G_CALLBACK (on_program_stopped), self);
-		g_signal_handlers_disconnect_by_func (self->debugger, G_CALLBACK (on_frame_changed), self);
-		g_object_unref (self->debugger);	
-	}
+	g_signal_handlers_disconnect_matched (self->plugin, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, self);	
 
 	/* Remove menu actions */
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (self->plugin)->shell, NULL);
