@@ -341,9 +341,7 @@ on_editor_command_upper_case_activate (GtkAction *action, gpointer user_data)
 														NULL);
 			end = ianjuta_editor_selection_get_end (IANJUTA_EDITOR_SELECTION (doc), NULL);			
 			ianjuta_editor_convert_to_upper (IANJUTA_EDITOR_CONVERT (doc), 
-											 ianjuta_iterable_get_position (start, NULL),
-											 ianjuta_iterable_get_position (end, NULL),
-											 NULL);
+											 start, end, NULL);
 			g_object_unref (start);
 			g_object_unref (end);			
 		}
@@ -364,11 +362,9 @@ on_editor_command_lower_case_activate (GtkAction *action, gpointer user_data)
 			start = ianjuta_editor_selection_get_start (IANJUTA_EDITOR_SELECTION (doc), NULL);
 			end = ianjuta_editor_selection_get_end (IANJUTA_EDITOR_SELECTION (doc), NULL);			
 			ianjuta_editor_convert_to_lower (IANJUTA_EDITOR_CONVERT (doc), 
-											 ianjuta_iterable_get_position (start, NULL),
-											 ianjuta_iterable_get_position (end, NULL),
-											 NULL);
+											 start, end, NULL);
 			g_object_unref (start);
-			g_object_unref (end);			
+			g_object_unref (end);
 		}
 	}
 }
@@ -413,21 +409,23 @@ on_editor_command_select_all_activate (GtkAction *action, gpointer user_data)
 	
 	widget = get_current_focus_widget (user_data);
 
-/*	if (widget && GTK_IS_EDITABLE (widget))
+	if (widget && GTK_IS_EDITABLE (widget))
 	{
 		gtk_editable_select_region (GTK_EDITABLE (widget), 0, -1);
 	}
-	else */
-	if (widget /* editor text is focused */
-		|| get_current_popup_active (user_data))
+	else
 	{
-		IAnjutaDocument *doc;
-
-		doc = get_current_document (user_data);
-		if (doc)
-			ianjuta_editor_selection_select_all
+		if (widget /* editor text is focused */
+			|| get_current_popup_active (user_data))
+		{
+			IAnjutaDocument *doc;
+			
+			doc = get_current_document (user_data);
+			if (doc)
+				ianjuta_editor_selection_select_all
 				(IANJUTA_EDITOR_SELECTION (doc), NULL);
 	}
+	}
 }
 
 void
@@ -487,19 +485,21 @@ on_editor_command_cut_activate (GtkAction *action, gpointer user_data)
 
 	widget = get_current_focus_widget (user_data);
 
-/*	if (widget && GTK_IS_EDITABLE (widget))
+	if (widget && GTK_IS_EDITABLE (widget))
 	{
 		gtk_editable_cut_clipboard (GTK_EDITABLE (widget));
 	}
-	else */
-	if (widget /* editor text is focused */
-		|| get_current_popup_active (user_data))
+	else
 	{
-		IAnjutaDocument *doc;
-
-		doc = get_current_document (user_data);
-		if (doc)
-			ianjuta_document_cut (doc, NULL);
+		if (widget /* editor text is focused */
+			|| get_current_popup_active (user_data))
+		{
+			IAnjutaDocument *doc;
+			
+			doc = get_current_document (user_data);
+			if (doc)
+				ianjuta_document_cut (doc, NULL);
+		}
 	}
 }
 
@@ -510,19 +510,20 @@ on_editor_command_paste_activate (GtkAction *action, gpointer user_data)
 
 	widget = get_current_focus_widget (user_data);
 
-/*	if (widget && GTK_IS_EDITABLE (widget))
+	if (widget && GTK_IS_EDITABLE (widget))
 	{
 		gtk_editable_paste_clipboard (GTK_EDITABLE (widget));
 	}
-	else */
-	if (widget	/* editor text is focused */
-		|| get_current_popup_active (user_data))
 	{
-		IAnjutaDocument *doc;
-
-		doc = get_current_document (user_data);
-		if (doc)
-			ianjuta_document_paste (doc, NULL);
+		if (widget	/* editor text is focused */
+			|| get_current_popup_active (user_data))
+		{
+			IAnjutaDocument *doc;
+			
+			doc = get_current_document (user_data);
+			if (doc)
+				ianjuta_document_paste (doc, NULL);
+		}
 	}
 }
 
@@ -533,19 +534,21 @@ on_editor_command_copy_activate (GtkAction *action, gpointer user_data)
 
 	widget = get_current_focus_widget (user_data);
 
-/*	if (widget && GTK_IS_EDITABLE (widget))
+	if (widget && GTK_IS_EDITABLE (widget))
 	{
 		gtk_editable_copy_clipboard (GTK_EDITABLE (widget));
 	}
-	else */
-	if (widget /* editor text is focused */
-		|| get_current_popup_active (user_data))
+	else
 	{
-		IAnjutaDocument *doc;
-
-		doc = get_current_document (user_data);
-		if (doc)
-			ianjuta_document_copy (doc, NULL);
+		if (widget /* editor text is focused */
+			|| get_current_popup_active (user_data))
+		{
+			IAnjutaDocument *doc;
+			
+			doc = get_current_document (user_data);
+			if (doc)
+				ianjuta_document_copy (doc, NULL);
+		}
 	}
 }
 
@@ -556,7 +559,7 @@ on_editor_command_clear_activate (GtkAction *action, gpointer user_data)
 
 	widget = get_current_focus_widget (user_data);
 
-/*	if (widget && GTK_IS_EDITABLE (widget))
+	if (widget && GTK_IS_EDITABLE (widget))
 	{
 		gint start, end;
 		if (!gtk_editable_get_selection_bounds (GTK_EDITABLE (widget), &start, &end))
@@ -566,8 +569,7 @@ on_editor_command_clear_activate (GtkAction *action, gpointer user_data)
 		}
 		gtk_editable_delete_text (GTK_EDITABLE (widget), start, end);
 	}
-	else */
-	if (widget	/* editor text is focused */
+	else if (widget	/* editor text is focused */
 		|| get_current_popup_active (user_data))
 	{
 		IAnjutaDocument *doc;
