@@ -33,8 +33,10 @@
 
 #include <libanjuta/interfaces/ianjuta-debugger.h>
 #include <libanjuta/interfaces/ianjuta-debugger-breakpoint.h>
-#include <libanjuta/interfaces/ianjuta-cpu-debugger.h>
-#include <libanjuta/interfaces/ianjuta-variable-debugger.h>
+#include <libanjuta/interfaces/ianjuta-debugger-register.h>
+#include <libanjuta/interfaces/ianjuta-debugger-memory.h>
+#include <libanjuta/interfaces/ianjuta-debugger-instruction.h>
+#include <libanjuta/interfaces/ianjuta-debugger-variable.h>
 #include <libanjuta/interfaces/ianjuta-terminal.h>
 #include <libanjuta/anjuta-plugin.h>
 #include <signal.h>
@@ -112,7 +114,7 @@ gdb_plugin_start_terminal (GdbPlugin* plugin)
 	if (mkfifo (file, 0664) < 0)
 	{
 		anjuta_util_dialog_error (GTK_WINDOW (ANJUTA_PLUGIN (plugin)->shell),
-					  _("Fail to create fifo file named %s. The program will be run without a terminal"), file);
+					  _("Fail to create fifo file named %s. The program will be run without a terminal."), file);
 		g_free (file);
 
 		return NULL;
@@ -306,8 +308,13 @@ idebugger_load (IAnjutaDebugger *plugin, const gchar *file, const gchar* mime_ty
 	gboolean is_libtool = FALSE;
 
 	/* Check allowed mime type */
-	if (strcmp (mime_type, "application/x-executable") == 0)
+	if (mime_type == NULL)
 	{
+		/* Hope that the target is supported */
+	}
+	else if (strcmp (mime_type, "application/x-executable") == 0)
+	{
+		/* Supported target */
 	}
 	else if (strcmp (mime_type, "application/x-shellscript") == 0)
 	{
@@ -318,16 +325,14 @@ idebugger_load (IAnjutaDebugger *plugin, const gchar *file, const gchar* mime_ty
 	}
 	else if (strcmp (mime_type, "application/x-core") == 0)
 	{
+		/* Supported target */
 	}
 	else
 	{
-		//return IANJUTA_DEBUGGER_NOT_IMPLEMENTED;
+		/* Not supported target */
 		return TRUE;
 	}
 	
-	// a NULL filename could be used to check supported mime type
-	if (file == NULL) return TRUE;
-		
 	// Start debugger
 	gdb_plugin_initialize (this);
 	
@@ -358,13 +363,13 @@ idebugger_attach (IAnjutaDebugger *plugin, pid_t pid, const GList *search_dirs,
 }
 
 static gboolean
-idebugger_start (IAnjutaDebugger *plugin, const gchar *argument, gboolean terminal, GError **err)
+idebugger_start (IAnjutaDebugger *plugin, const gchar *argument, gboolean terminal, gboolean stop, GError **err)
 {
 	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
 	gchar *tty;
 
 	tty = terminal ? gdb_plugin_start_terminal (this) : NULL;
-	debugger_start_program (this->debugger, argument, tty);
+	debugger_start_program (this->debugger, argument, tty, stop);
 	g_free (tty);
 
 	return TRUE;
@@ -806,7 +811,7 @@ idebugger_breakpoint_add_at_function (IAnjutaDebuggerBreakpoint *plugin, const g
 }
 
 static gboolean
-idebugger_breakpoint_add_at_address (IAnjutaDebuggerBreakpoint *plugin, guint address, IAnjutaDebuggerCallback callback, gpointer user_data, GError **err)
+idebugger_breakpoint_add_at_address (IAnjutaDebuggerBreakpoint *plugin, gulong address, IAnjutaDebuggerCallback callback, gpointer user_data, GError **err)
 {
 	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
 	
@@ -879,11 +884,11 @@ idebugger_breakpoint_iface_init (IAnjutaDebuggerBreakpointIface *iface)
 	iface->condition = idebugger_breakpoint_condition;
 }
 
-/* Implementation of IAnjutaCpuDebugger interface
+/* Implementation of IAnjutaDebuggerRegister interface
  *---------------------------------------------------------------------------*/
 
 static gboolean
-icpu_debugger_list_register (IAnjutaCpuDebugger *plugin, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
+idebugger_register_list (IAnjutaDebuggerRegister *plugin, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
 {
 	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
 
@@ -893,7 +898,7 @@ icpu_debugger_list_register (IAnjutaCpuDebugger *plugin, IAnjutaDebuggerCallback
 }
 
 static gboolean
-icpu_debugger_update_register (IAnjutaCpuDebugger *plugin, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
+idebugger_register_update (IAnjutaDebuggerRegister *plugin, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
 {
 	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
 
@@ -903,7 +908,7 @@ icpu_debugger_update_register (IAnjutaCpuDebugger *plugin, IAnjutaDebuggerCallba
 }
 
 static gboolean
-icpu_debugger_write_register (IAnjutaCpuDebugger *plugin, IAnjutaDebuggerRegister *value, GError **err)
+idebugger_register_write (IAnjutaDebuggerRegister *plugin, IAnjutaDebuggerRegisterData *value, GError **err)
 {
 	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
 
@@ -912,8 +917,19 @@ icpu_debugger_write_register (IAnjutaCpuDebugger *plugin, IAnjutaDebuggerRegiste
 	return TRUE;
 }
 
+static void
+idebugger_register_iface_init (IAnjutaDebuggerRegisterIface *iface)
+{
+	iface->list = idebugger_register_list;
+	iface->update = idebugger_register_update;
+	iface->write = idebugger_register_write;
+}
+
+/* Implementation of IAnjutaDebuggerMemory interface
+ *---------------------------------------------------------------------------*/
+
 static gboolean
-icpu_debugger_inspect_memory (IAnjutaCpuDebugger *plugin, guint address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
+idebugger_memory_inspect (IAnjutaDebuggerMemory *plugin, gulong address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
 {
 	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
 
@@ -922,8 +938,17 @@ icpu_debugger_inspect_memory (IAnjutaCpuDebugger *plugin, guint address, guint l
 	return TRUE;
 }
 
+static void
+idebugger_memory_iface_init (IAnjutaDebuggerMemoryIface *iface)
+{
+	iface->inspect = idebugger_memory_inspect;
+}
+
+/* Implementation of IAnjutaDebuggerInstruction interface
+ *---------------------------------------------------------------------------*/
+
 static gboolean
-icpu_debugger_disassemble (IAnjutaCpuDebugger *plugin, guint address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
+idebugger_instruction_disassemble (IAnjutaDebuggerInstruction *plugin, gulong address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
 {
 	GdbPlugin *this = (GdbPlugin *)plugin;
 
@@ -932,21 +957,50 @@ icpu_debugger_disassemble (IAnjutaCpuDebugger *plugin, guint address, guint leng
 	return TRUE;
 }
 
-static void
-icpu_debugger_iface_init (IAnjutaCpuDebuggerIface *iface)
+static gboolean
+idebugger_instruction_step_in (IAnjutaDebuggerInstruction *plugin, GError **err)
 {
-	iface->list_register = icpu_debugger_list_register;
-	iface->update_register = icpu_debugger_update_register;
-	iface->write_register = icpu_debugger_write_register;
-	iface->inspect_memory = icpu_debugger_inspect_memory;
-	iface->disassemble = icpu_debugger_disassemble;
+	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
+	
+	debugger_stepi_in (this->debugger);
+
+	return TRUE;
 }
 
-/* Implementation of IAnjutaVariableDebugger interface
+static gboolean
+idebugger_instruction_step_over (IAnjutaDebuggerInstruction *plugin, GError **err)
+{
+	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
+	
+	debugger_stepi_over (this->debugger);
+
+	return TRUE;
+}
+
+static gboolean
+idebugger_instruction_run_to_address (IAnjutaDebuggerInstruction *plugin, gulong address, GError **err)
+{
+	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
+	
+	debugger_run_to_address (this->debugger, address);
+
+	return TRUE;
+}
+
+static void
+idebugger_instruction_iface_init (IAnjutaDebuggerInstructionIface *iface)
+{
+	iface->disassemble = idebugger_instruction_disassemble;
+	iface->step_in = idebugger_instruction_step_in;
+	iface->step_over = idebugger_instruction_step_over;
+	iface->run_to_address = idebugger_instruction_run_to_address;
+}
+
+/* Implementation of IAnjutaDebuggerVariable interface
  *---------------------------------------------------------------------------*/
 
 static gboolean
-ivariable_debugger_delete (IAnjutaVariableDebugger *plugin, const gchar *name, GError **error)
+idebugger_variable_destroy (IAnjutaDebuggerVariable *plugin, const gchar *name, GError **error)
 {
 	GdbPlugin *gdb = ANJUTA_PLUGIN_GDB (plugin);
 
@@ -956,7 +1010,7 @@ ivariable_debugger_delete (IAnjutaVariableDebugger *plugin, const gchar *name, G
 }
 
 static gboolean
-ivariable_debugger_evaluate (IAnjutaVariableDebugger *plugin, const gchar *name, IAnjutaDebuggerCallback callback , gpointer user_data, GError **error)
+idebugger_variable_evaluate (IAnjutaDebuggerVariable *plugin, const gchar *name, IAnjutaDebuggerCallback callback , gpointer user_data, GError **error)
 {
 	GdbPlugin *gdb = ANJUTA_PLUGIN_GDB (plugin);
 
@@ -966,7 +1020,7 @@ ivariable_debugger_evaluate (IAnjutaVariableDebugger *plugin, const gchar *name,
 }
 
 static gboolean
-ivariable_debugger_assign (IAnjutaVariableDebugger *plugin, const gchar *name, const gchar *value, GError **error)
+idebugger_variable_assign (IAnjutaDebuggerVariable *plugin, const gchar *name, const gchar *value, GError **error)
 {
 	GdbPlugin *gdb = ANJUTA_PLUGIN_GDB (plugin);
 
@@ -976,7 +1030,7 @@ ivariable_debugger_assign (IAnjutaVariableDebugger *plugin, const gchar *name, c
 }
 
 static gboolean
-ivariable_debugger_list_children (IAnjutaVariableDebugger *plugin, const gchar *name, IAnjutaDebuggerCallback callback , gpointer user_data, GError **error)
+idebugger_variable_list_children (IAnjutaDebuggerVariable *plugin, const gchar *name, IAnjutaDebuggerCallback callback , gpointer user_data, GError **error)
 {
 	GdbPlugin *gdb = ANJUTA_PLUGIN_GDB (plugin);
 
@@ -986,7 +1040,7 @@ ivariable_debugger_list_children (IAnjutaVariableDebugger *plugin, const gchar *
 }
 
 static gboolean
-ivariable_debugger_create (IAnjutaVariableDebugger *plugin, const gchar *name, IAnjutaDebuggerCallback callback , gpointer user_data, GError **error)
+idebugger_variable_create (IAnjutaDebuggerVariable *plugin, const gchar *name, IAnjutaDebuggerCallback callback , gpointer user_data, GError **error)
 {
 	GdbPlugin *gdb = ANJUTA_PLUGIN_GDB (plugin);
 
@@ -996,7 +1050,7 @@ ivariable_debugger_create (IAnjutaVariableDebugger *plugin, const gchar *name, I
 }
 
 static gboolean
-ivariable_debugger_update (IAnjutaVariableDebugger *plugin, IAnjutaDebuggerCallback callback , gpointer user_data, GError **error)
+idebugger_variable_update (IAnjutaDebuggerVariable *plugin, IAnjutaDebuggerCallback callback , gpointer user_data, GError **error)
 {
 	GdbPlugin *gdb = ANJUTA_PLUGIN_GDB (plugin);
 
@@ -1006,21 +1060,23 @@ ivariable_debugger_update (IAnjutaVariableDebugger *plugin, IAnjutaDebuggerCallb
 }
 
 static void
-ivariable_debugger_iface_init (IAnjutaVariableDebuggerIface *iface)
+idebugger_variable_iface_init (IAnjutaDebuggerVariableIface *iface)
 {
-	iface->delete_var = ivariable_debugger_delete;
-	iface->evaluate = ivariable_debugger_evaluate;
-	iface->assign = ivariable_debugger_assign;
-	iface->list_children = ivariable_debugger_list_children;
-	iface->create = ivariable_debugger_create;
-	iface->update = ivariable_debugger_update;
+	iface->destroy = idebugger_variable_destroy;
+	iface->evaluate = idebugger_variable_evaluate;
+	iface->assign = idebugger_variable_assign;
+	iface->list_children = idebugger_variable_list_children;
+	iface->create = idebugger_variable_create;
+	iface->update = idebugger_variable_update;
 }
 
 ANJUTA_PLUGIN_BEGIN (GdbPlugin, gdb_plugin);
 ANJUTA_PLUGIN_ADD_INTERFACE(idebugger, IANJUTA_TYPE_DEBUGGER);
 ANJUTA_PLUGIN_ADD_INTERFACE(idebugger_breakpoint, IANJUTA_TYPE_DEBUGGER_BREAKPOINT);
-ANJUTA_PLUGIN_ADD_INTERFACE(icpu_debugger, IANJUTA_TYPE_CPU_DEBUGGER);
-ANJUTA_PLUGIN_ADD_INTERFACE(ivariable_debugger, IANJUTA_TYPE_VARIABLE_DEBUGGER);
+ANJUTA_PLUGIN_ADD_INTERFACE(idebugger_register, IANJUTA_TYPE_DEBUGGER_REGISTER);
+ANJUTA_PLUGIN_ADD_INTERFACE(idebugger_memory, IANJUTA_TYPE_DEBUGGER_MEMORY);
+ANJUTA_PLUGIN_ADD_INTERFACE(idebugger_instruction, IANJUTA_TYPE_DEBUGGER_INSTRUCTION);
+ANJUTA_PLUGIN_ADD_INTERFACE(idebugger_variable, IANJUTA_TYPE_DEBUGGER_VARIABLE);
 ANJUTA_PLUGIN_END;
 
 ANJUTA_SIMPLE_PLUGIN (GdbPlugin, gdb_plugin);
