@@ -397,6 +397,17 @@ inspector_item_activated_cb (GladeInspector     *inspector,
 	
 	g_list_free (item);
 }
+
+static void
+on_glade_resource_removed (GladeProject *project, GladePlugin *plugin)
+{
+}
+
+static void
+on_glade_resource_updated (GladeProject *project, GladePlugin *plugin)
+{
+}
+
 #endif
 
 static gboolean
@@ -630,8 +641,8 @@ ifile_open (IAnjutaFile *ifile, const gchar *uri, GError **err)
 	GtkTreeIter iter;
 	gchar *filename;
 	IAnjutaDocumentManager* docman;
-	GList* docwids;
-	GList* node;
+	GList* docwids, *node;
+	const GList *glade_obj_node;
 	
 	g_return_if_fail (uri != NULL);
 	
@@ -676,6 +687,15 @@ ifile_open (IAnjutaFile *ifile, const gchar *uri, GError **err)
 	
 #if (GLADEUI_VERSION >= 330)
 	project = glade_project_load (filename);
+	if (project)
+	{
+		g_signal_connect (project, "resource-removed",
+						  G_CALLBACK (on_glade_resource_removed),
+						  ANJUTA_PLUGIN_GLADE (ifile));
+		g_signal_connect (project, "resource-updated",
+						  G_CALLBACK (on_glade_resource_updated),
+						  ANJUTA_PLUGIN_GLADE (ifile));
+	}
 #else
 	project = glade_project_open (filename);
 #endif
@@ -696,6 +716,17 @@ ifile_open (IAnjutaFile *ifile, const gchar *uri, GError **err)
 						PROJECT_COL, project, -1);
 #endif
 	glade_plugin_add_project (ANJUTA_PLUGIN_GLADE (ifile), project);
+
+	/* Select the first window in the project */
+	for (glade_obj_node = glade_project_get_objects (project);
+		 glade_obj_node != NULL;
+		 glade_obj_node = g_list_next (glade_obj_node))
+	{
+		GObject *glade_obj = G_OBJECT (glade_obj_node->data);
+		if (GTK_IS_WINDOW (glade_obj))
+			glade_widget_show (glade_widget_get_from_gobject (glade_obj));
+		break;
+	}
 	anjuta_shell_present_widget (ANJUTA_PLUGIN (ifile)->shell, priv->view_box, NULL);
 }
 
@@ -736,6 +767,13 @@ iwizard_activate (IAnjutaWizard *iwizard, GError **err)
 
 #if (GLADEUI_VERSION >= 330)
 	project = glade_project_new ();
+	
+	g_signal_connect (project, "resource-removed",
+					  G_CALLBACK (on_glade_resource_removed),
+					  ANJUTA_PLUGIN_GLADE (iwizard));
+	g_signal_connect (project, "resource-updated",
+					  G_CALLBACK (on_glade_resource_updated),
+					  ANJUTA_PLUGIN_GLADE (iwizard));
 #else
 	project = glade_project_new (TRUE);
 #endif
