@@ -67,10 +67,13 @@ static gboolean find_incremental(IAnjutaEditor* te, gchar* expression,
 	
 	if (info != NULL)
 	{
-		gboolean backward;
-		backward = dir == SD_BACKWARD?TRUE:FALSE;
+		IAnjutaIterable *start, *end;
+		start = ianjuta_editor_get_position_from_offset (te, info->pos, NULL);
+		end = ianjuta_editor_get_position_from_offset (te, info->pos + info->len, NULL);
 		ianjuta_editor_selection_set (IANJUTA_EDITOR_SELECTION (te),
-									  info->pos, info->pos + info->len, backward, NULL);
+									  start, end, NULL);
+		g_object_unref (start);
+		g_object_unref (end);
 		ret = TRUE;
 	}
 	else
@@ -188,7 +191,7 @@ on_next_occur(GtkAction * action, gpointer user_data)
 
 static GtkActionEntry actions_search[] = {
   { "ActionMenuEditSearch", NULL, N_("_Search"), NULL, NULL, NULL},
-  { "ActionEditSearchFind", GTK_STOCK_FIND, N_("_Find..."), "<shift><control>f",
+  { "ActionEditSearchFind", GTK_STOCK_FIND, N_("_Find..."), "<control><alt>f",
 	N_("Search for a string or regular expression in the editor"),
     G_CALLBACK (on_find1_activate)},
   { "ActionEditSearchFindNext", GTK_STOCK_FIND, N_("Find _Next"), "<control>g",
