@@ -179,8 +179,8 @@ file_buffer_new_from_te (IAnjutaEditor *te)
 		g_free (uri);
 	}
 	fb->len = ianjuta_editor_get_length(te, NULL);
-	fb->buf = ianjuta_editor_get_text(fb->te, 0, fb->len, NULL);
-	fb->pos = ianjuta_editor_get_position(fb->te, NULL);
+	fb->buf = ianjuta_editor_get_text_all (fb->te, NULL);
+	fb->pos = ianjuta_editor_get_offset(fb->te, NULL);
 	fb->line = ianjuta_editor_get_lineno(fb->te, NULL);
 	
 	return fb;
@@ -301,7 +301,11 @@ file_buffer_line_from_pos(FileBuffer *fb, int pos)
 	}
 	else if (FB_EDITOR == fb->type)
 	{
-		return ianjuta_editor_get_line_from_position(fb->te, pos, NULL);
+		IAnjutaIterable *position;
+		position = ianjuta_editor_get_position_from_offset (fb->te, pos, NULL);
+		lineno = ianjuta_editor_get_line_from_position (fb->te, position, NULL);
+		g_object_unref (position);
+		return lineno;
 	}
 	else
 		return -1;
@@ -591,8 +595,8 @@ create_search_entries (Search *s)
 	GList *editors;
 	IAnjutaDocument *doc;
 	SearchEntry *se;
-	gint selstart;
 	gint tmp_pos;
+	gint selstart;
 
 	switch (s->range.type)
 	{
@@ -612,27 +616,34 @@ create_search_entries (Search *s)
 				}
 				else
 				{	
+					IAnjutaIterable *start;
 					/* forward-search from after beginning of selection, if any
 					   backwards-search from before beginning of selection, if any
 					   treat -ve positions except -1 as high +ve */
-					selstart = ianjuta_editor_selection_get_start
+					start = ianjuta_editor_selection_get_start
 							(IANJUTA_EDITOR_SELECTION (se->te), NULL);
-					if (selstart != -1)
+					if (start)
 					{
+						selstart =
+							ianjuta_iterable_get_position (start, NULL);
 						if (se->direction == SD_BACKWARD)
 						{
 							se->start_pos = (selstart != 0) ?
 								 selstart - 1 : selstart;
 						}
 						else
+						{
 							se->start_pos =
 								(selstart != -2 &&
 								 selstart < ianjuta_editor_get_length (IANJUTA_EDITOR (se->te), NULL)) ?
 								 selstart + 1 : selstart;
+						}
+						g_object_unref (start);
 					}
 					else
-						se->start_pos = ianjuta_editor_get_position (se->te, NULL);
-
+					{
+						se->start_pos = ianjuta_editor_get_offset (se->te, NULL);
+					}
 					se->end_pos = -1;	/* not actually used when backward searching */
 				}
 				entries = g_list_prepend(entries, se);
@@ -659,17 +670,33 @@ create_search_entries (Search *s)
 				}				
 				else
 				{
-					selstart = selend =
-					ianjuta_editor_selection_get_end (IANJUTA_EDITOR_SELECTION (se->te), NULL);
+					IAnjutaIterable* end =
+						ianjuta_editor_selection_get_end (IANJUTA_EDITOR_SELECTION (se->te), NULL);
+					if (end)
+					{
+						selstart = selend = ianjuta_iterable_get_position (end, NULL);
+						g_object_unref (end);
+					}
+					else
+					{
+						selstart = selend = 0;	/* warning prevention only */
+						g_assert ("No selection end position");
+					}
 				}
 
 				if (s->range.type == SR_BLOCK)
 					ianjuta_editor_selection_select_block(IANJUTA_EDITOR_SELECTION (se->te), NULL);
 				if (s->range.type == SR_FUNCTION)
 					ianjuta_editor_selection_select_function(IANJUTA_EDITOR_SELECTION (se->te), NULL);
-				se->start_pos = ianjuta_editor_selection_get_start(IANJUTA_EDITOR_SELECTION (se->te), NULL);
-				se->end_pos = ianjuta_editor_selection_get_end(IANJUTA_EDITOR_SELECTION (se->te), NULL);
-			
+				{
+					IAnjutaIterable *start, *end;
+					start = ianjuta_editor_selection_get_start (IANJUTA_EDITOR_SELECTION (se->te), NULL);
+					end = ianjuta_editor_selection_get_end(IANJUTA_EDITOR_SELECTION (se->te), NULL);
+					se->start_pos =  ianjuta_iterable_get_position (start, NULL);
+					se->end_pos = ianjuta_iterable_get_position (end, NULL);
+					g_object_unref (start);
+					g_object_unref (end);
+				}
 				if (se->direction == SD_BACKWARD)
 				{
 					tmp_pos = se->start_pos;
@@ -679,16 +706,18 @@ create_search_entries (Search *s)
 				entries = g_list_prepend (entries, se);
 				if (s->range.type != SR_SELECTION)
 				{
-					gboolean backward;
-					backward = (se->direction == SD_BACKWARD);
+					IAnjutaIterable *start, *end;
+					start = ianjuta_editor_get_position_from_offset (se->te, selstart, NULL);
+					end = ianjuta_editor_get_position_from_offset (se->te, selend, NULL);
 					ianjuta_editor_selection_set(IANJUTA_EDITOR_SELECTION (se->te), 
-				                                 selstart, selend, backward,
-				                                 NULL);	
-				}					
+				                                 start, end, NULL);	
+					g_object_unref (start);
+					g_object_unref (end);
+				}
 			}
 			break;
 		case SR_OPEN_BUFFERS:
-			editors = ianjuta_document_manager_get_documents (sr->docman, NULL);
+			editors = ianjuta_document_manager_get_doc_widgets (sr->docman, NULL);
 			for (tmp = editors; tmp; tmp = g_list_next(tmp))
 			{
 				if (IANJUTA_IS_EDITOR (tmp->data))
