@@ -19,7 +19,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "sourceview-cell.h"
@@ -32,15 +32,13 @@
 
 #include <gtk/gtktextview.h>
 #include <string.h>
-
-#include <gtksourceview/gtksourcetag.h>
  
 static void sourceview_cell_class_init(SourceviewCellClass *klass);
 static void sourceview_cell_instance_init(SourceviewCell *sp);
 static void sourceview_cell_finalize(GObject *object);
 
 struct _SourceviewCellPrivate {
-	GtkTextMark* mark;
+	GtkTextIter* iter;
 	GtkTextView* view;
 	GtkTextBuffer* buffer;
 };
@@ -60,7 +58,7 @@ sourceview_cell_class_init(SourceviewCellClass *klass)
 static void
 sourceview_cell_instance_init(SourceviewCell *obj)
 {
-	obj->priv = g_new0(SourceviewCellPrivate, 1);
+	obj->priv = g_slice_new(SourceviewCellPrivate);
 	
 	/* Initialize private members, etc. */	
 }
@@ -71,9 +69,9 @@ sourceview_cell_finalize(GObject *object)
 	SourceviewCell *cobj;
 	cobj = SOURCEVIEW_CELL(object);
 	
-	gtk_text_buffer_delete_mark(cobj->priv->buffer, cobj->priv->mark);
+  gtk_text_iter_free(cobj->priv->iter);
 	
-	g_free(cobj->priv);
+	g_slice_free(SourceviewCellPrivate, cobj->priv);
 	G_OBJECT_CLASS(sourceview_cell_parent_class)->finalize(object);
 }
 
@@ -85,25 +83,25 @@ sourceview_cell_new(GtkTextIter* iter, GtkTextView* view)
 	obj = SOURCEVIEW_CELL(g_object_new(SOURCEVIEW_TYPE_CELL, NULL));
 	
 	obj->priv->buffer = gtk_text_view_get_buffer(view);
-	obj->priv->mark = gtk_text_buffer_create_mark(obj->priv->buffer,
-												  NULL,
-												  iter,
-												  FALSE);
+	obj->priv->iter = gtk_text_iter_copy (iter);
 	obj->priv->view = view;
 	
 	return obj;
 }
 
+GtkTextIter* 
+sourceview_cell_get_iter (SourceviewCell* cell)
+{
+	return cell->priv->iter;
+}
+
 static gchar*
 icell_get_character(IAnjutaEditorCell* icell, GError** e)
 {
 	SourceviewCell* cell = SOURCEVIEW_CELL(icell);
-	GtkTextIter iter;
 	gchar outbuf[7];
 	int length;	
-	gtk_text_buffer_get_iter_at_mark(cell->priv->buffer, &iter,
-									 cell->priv->mark);
-	length = g_unichar_to_utf8(gtk_text_iter_get_char(&iter), outbuf);
+	length = g_unichar_to_utf8(gtk_text_iter_get_char(cell->priv->iter), outbuf);
 	outbuf[length] = '\0';
 	return g_strdup(outbuf);
 }
@@ -112,10 +110,7 @@ static gint
 icell_get_length(IAnjutaEditorCell* icell, GError** e)
 {
 	SourceviewCell* cell = SOURCEVIEW_CELL(icell);
-	GtkTextIter iter;
-	gtk_text_buffer_get_iter_at_mark(cell->priv->buffer, &iter,
-									 cell->priv->mark);
-	return g_unichar_to_utf8(gtk_text_iter_get_char(&iter), NULL);
+	return g_unichar_to_utf8(gtk_text_iter_get_char(cell->priv->iter), NULL);
 }
 
 static gchar
@@ -123,15 +118,9 @@ icell_get_char(IAnjutaEditorCell* icell, gint index, GError** e)
 {
 	gchar ch = '\0';
 	gchar* utf8 = icell_get_character(icell, NULL);
-	gsize bytes_written, bytes_read;
-	GError* error = NULL;
-	gchar* locale = g_locale_from_utf8(utf8, -1, &bytes_read, &bytes_written, &error);
-	if (error)
-		DEBUG_PRINT("Error: %s", error->message);
-	if (bytes_written >= 1)
-		ch = locale[0];	
+	if (strlen (utf8) > index)
+		ch = utf8[index];	
 	g_free(utf8);
-	g_free(locale);
 	return ch;
 }
 
@@ -140,13 +129,10 @@ icell_get_attribute (IAnjutaEditorCell* icell, GError **e)
 {
 	SourceviewCell* cell = SOURCEVIEW_CELL(icell);
 	IAnjutaEditorAttribute attrib = IANJUTA_EDITOR_TEXT;
-	GtkTextIter iter;
 	GSList* tags;
-	gtk_text_buffer_get_iter_at_mark(cell->priv->buffer, &iter,
-									 cell->priv->mark);
 	/* This is a kind of ugly hack. GtkSourceview does not really expose an
 		API to get the type of tag but the id holds the important stuff */
-	for (tags = gtk_text_iter_get_tags(&iter); tags != NULL; tags = tags->next)
+	/*for (tags = gtk_text_iter_get_tags(cell->priv->iter); tags != NULL; tags = tags->next)
 	{
 		if (GTK_IS_SOURCE_TAG(tags->data))
 		{
@@ -162,17 +148,16 @@ icell_get_attribute (IAnjutaEditorCell* icell, GError **e)
 				attrib = IANJUTA_EDITOR_COMMENT;
 				break;
 			}
-			if (g_str_has_prefix(id, "String") || g_str_has_suffix(id, "String"))
+			if (g_str_has_prefix(id, "String") || g_str_has_suffix(id, "String") ||
+					g_str_equal (id, "Character Constant"))
 			{
 				attrib = IANJUTA_EDITOR_STRING;
 				break;
 			}
-			else
-				;
-				//DEBUG_PRINT("unknown GtkSourceTag id = %s", id);
+			//DEBUG_PRINT("GtkSourceTag tag_style = %s", id);
 		}
 	}
-	g_slist_free(tags);
+	g_slist_free(tags);*/
 	return attrib;
 }
 
@@ -188,9 +173,9 @@ icell_iface_init(IAnjutaEditorCellIface* iface)
 static
 GtkTextAttributes* get_attributes(GtkTextIter* iter, GtkTextView* view)
 {
-	GtkTextAttributes* atts = gtk_text_view_get_default_attributes(view);
-	gtk_text_iter_get_attributes(iter, atts);
-	return atts;
+  GtkTextAttributes* atts = gtk_text_view_get_default_attributes(view);
+  gtk_text_iter_get_attributes(iter, atts);
+  return atts;
 }
 
 static gchar*
@@ -198,10 +183,7 @@ icell_style_get_font_description(IAnjutaEditorCellStyle* icell_style, GError **
 {
 	const gchar* font;
 	SourceviewCell* cell = SOURCEVIEW_CELL(icell_style);
-	GtkTextIter iter;
-	gtk_text_buffer_get_iter_at_mark(cell->priv->buffer, &iter,
-									 cell->priv->mark);
-	GtkTextAttributes* atts = get_attributes(&iter, 
+	GtkTextAttributes* atts = get_attributes(cell->priv->iter, 
 											 cell->priv->view);
 	font = pango_font_description_to_string(atts->font);
 	g_free(atts);
@@ -213,10 +195,7 @@ icell_style_get_color(IAnjutaEditorCellStyle* icell_style, GError ** e)
 {
 	gchar* color;
 	SourceviewCell* cell = SOURCEVIEW_CELL(icell_style);
-	GtkTextIter iter;
-	gtk_text_buffer_get_iter_at_mark(cell->priv->buffer, &iter,
-									 cell->priv->mark);
-	GtkTextAttributes* atts = get_attributes(&iter, cell->priv->view);
+	GtkTextAttributes* atts = get_attributes(cell->priv->iter, cell->priv->view);
 	color = anjuta_util_string_from_color(atts->appearance.fg_color.red,
 		atts->appearance.fg_color.green, atts->appearance.fg_color.blue);
 	g_free(atts);
@@ -228,10 +207,7 @@ icell_style_get_background_color(IAnjutaEditorCellStyle* icell_style, GError **
 {
 	gchar* color;
 	SourceviewCell* cell = SOURCEVIEW_CELL(icell_style);
-	GtkTextIter iter;
-	gtk_text_buffer_get_iter_at_mark(cell->priv->buffer, &iter,
-									 cell->priv->mark);
-	GtkTextAttributes* atts = get_attributes(&iter, cell->priv->view);
+	GtkTextAttributes* atts = get_attributes(cell->priv->iter, cell->priv->view);
 	color = anjuta_util_string_from_color(atts->appearance.bg_color.red,
 		atts->appearance.bg_color.green, atts->appearance.bg_color.blue);
 	g_free(atts);
@@ -250,11 +226,7 @@ static gboolean
 iiter_first(IAnjutaIterable* iter, GError** e)
 {
 	SourceviewCell* cell = SOURCEVIEW_CELL(iter);
-	GtkTextIter text_iter;
-	gtk_text_buffer_get_iter_at_mark(cell->priv->buffer, &text_iter,
-									 cell->priv->mark);
-	gtk_text_iter_set_offset(&text_iter, 0);
-	gtk_text_buffer_move_mark(cell->priv->buffer, cell->priv->mark, &text_iter);
+	gtk_text_iter_set_offset(cell->priv->iter, 0);
 	return TRUE;
 }
 
@@ -262,48 +234,24 @@ static gboolean
 iiter_next(IAnjutaIterable* iter, GError** e)
 {
 	SourceviewCell* cell = SOURCEVIEW_CELL(iter);
-	GtkTextIter text_iter;
-	
-	gtk_text_buffer_get_iter_at_mark(cell->priv->buffer, &text_iter,
-									 cell->priv->mark);
 
-	if (gtk_text_iter_forward_char(&text_iter))
-	{
-		gtk_text_buffer_move_mark(cell->priv->buffer, cell->priv->mark, &text_iter);
-		return TRUE;
-	}
-	else
-		return FALSE;
+	return gtk_text_iter_forward_char(cell->priv->iter);
 }
 
 static gboolean
 iiter_previous(IAnjutaIterable* iter, GError** e)
 {
 	SourceviewCell* cell = SOURCEVIEW_CELL(iter);
-	GtkTextIter text_iter;
 	
-	gtk_text_buffer_get_iter_at_mark(cell->priv->buffer, &text_iter,
-									 cell->priv->mark);
-
-	if (gtk_text_iter_backward_char(&text_iter))
-	{
-		gtk_text_buffer_move_mark(cell->priv->buffer, cell->priv->mark, &text_iter);
-		return TRUE;
-	}
-	else
-		return FALSE;
+	return gtk_text_iter_backward_char(cell->priv->iter);
 }
 
 static gboolean
 iiter_last(IAnjutaIterable* iter, GError** e)
 {
 	SourceviewCell* cell = SOURCEVIEW_CELL(iter);
-	GtkTextIter text_iter;
-	gtk_text_buffer_get_iter_at_mark(cell->priv->buffer, &text_iter,
-									 cell->priv->mark);
 
-	gtk_text_iter_forward_to_end(&text_iter);
-	iiter_previous (iter, NULL);
+	gtk_text_iter_forward_to_end(cell->priv->iter);
 	return TRUE;
 }
 
@@ -312,32 +260,23 @@ iiter_foreach(IAnjutaIterable* iter, GFunc callback, gpointer data, GError** e)
 {
 	SourceviewCell* cell = SOURCEVIEW_CELL(iter);
 	
-	GtkTextIter text_iter;
 	gint saved_offset;
 	
-	gtk_text_buffer_get_iter_at_mark(cell->priv->buffer, &text_iter,
-									 cell->priv->mark);
-	saved_offset = gtk_text_iter_get_offset (&text_iter);
-	gtk_text_iter_set_offset(&text_iter, 0);
-	while (gtk_text_iter_forward_char(&text_iter))
+	saved_offset = gtk_text_iter_get_offset (cell->priv->iter);
+	gtk_text_iter_set_offset(cell->priv->iter, 0);
+	while (gtk_text_iter_forward_char(cell->priv->iter))
 	{
-		gtk_text_buffer_move_mark(cell->priv->buffer, cell->priv->mark,
-								  &text_iter);
 		(*callback)(cell, data);
 	}
-	gtk_text_iter_set_offset(&text_iter, saved_offset);
+	gtk_text_iter_set_offset(cell->priv->iter, saved_offset);
 }
 
 static gboolean
 iiter_set_position (IAnjutaIterable* iter, gint position, GError** e)
 {
 	SourceviewCell* cell = SOURCEVIEW_CELL(iter);
-	GtkTextIter old_iter;
 
-	gtk_text_buffer_get_iter_at_mark(cell->priv->buffer, &old_iter,
-									 cell->priv->mark);
-	gtk_text_iter_set_offset (&old_iter, position);
-	gtk_text_buffer_move_mark (cell->priv->buffer, cell->priv->mark, &old_iter);
+	gtk_text_iter_set_offset (cell->priv->iter, position);
 	return TRUE;
 }
 
@@ -345,47 +284,51 @@ static gint
 iiter_get_position(IAnjutaIterable* iter, GError** e)
 {
 	SourceviewCell* cell = SOURCEVIEW_CELL(iter);
-	GtkTextIter text_iter;
-	gtk_text_buffer_get_iter_at_mark(cell->priv->buffer, &text_iter,
-									 cell->priv->mark);
-	return gtk_text_iter_get_offset(&text_iter);
+	return gtk_text_iter_get_offset(cell->priv->iter);
 }
 
 static gint
 iiter_get_length(IAnjutaIterable* iter, GError** e)
 {
 	SourceviewCell* cell = SOURCEVIEW_CELL(iter);
-	GtkTextIter text_iter;
-	gtk_text_buffer_get_iter_at_mark(cell->priv->buffer, &text_iter,
-									 cell->priv->mark);
 	
-	return gtk_text_buffer_get_char_count (gtk_text_iter_get_buffer(&text_iter));
+	return gtk_text_buffer_get_char_count (gtk_text_iter_get_buffer(cell->priv->iter));
 }
 
 static IAnjutaIterable *
 iiter_clone (IAnjutaIterable *iter, GError **e)
 {
-	GtkTextIter text_iter;
 	SourceviewCell* cell = SOURCEVIEW_CELL(iter);
 	
-	gtk_text_buffer_get_iter_at_mark(cell->priv->buffer, &text_iter,
-									 cell->priv->mark);
-	
-	return IANJUTA_ITERABLE (sourceview_cell_new (&text_iter, cell->priv->view));
+	return IANJUTA_ITERABLE (sourceview_cell_new (cell->priv->iter, cell->priv->view));
 }
 
 static void
 iiter_assign (IAnjutaIterable *iter, IAnjutaIterable *src_iter, GError **e)
 {
-	GtkTextIter text_iter;
 	SourceviewCell* cell = SOURCEVIEW_CELL(iter);
 	SourceviewCell* src_cell = SOURCEVIEW_CELL(src_iter);
 	
-	gtk_text_buffer_get_iter_at_mark(src_cell->priv->buffer, &text_iter,
-									 src_cell->priv->mark);
+	gtk_text_iter_free(cell->priv->iter);
+	cell->priv->iter = gtk_text_iter_copy (src_cell->priv->iter);
+}
+
+static gint
+iiter_compare (IAnjutaIterable *iter, IAnjutaIterable *other_iter, GError **e)
+{
+	SourceviewCell* cell = SOURCEVIEW_CELL(iter);
+	SourceviewCell* other_cell = SOURCEVIEW_CELL(other_iter);
 	
-	gtk_text_buffer_move_mark (cell->priv->buffer, cell->priv->mark,
-							   &text_iter);
+  return gtk_text_iter_compare (cell->priv->iter, other_cell->priv->iter);
+}
+
+static gint
+iiter_diff (IAnjutaIterable *iter, IAnjutaIterable *other_iter, GError **e)
+{
+	SourceviewCell* cell = SOURCEVIEW_CELL(iter);
+	SourceviewCell* other_cell = SOURCEVIEW_CELL(other_iter);
+	return (gtk_text_iter_get_offset (cell->priv->iter) 
+					- gtk_text_iter_get_offset (other_cell->priv->iter));
 }
 
 static void
@@ -401,6 +344,8 @@ iiter_iface_init(IAnjutaIterableIface* iface)
 	iface->get_length = iiter_get_length;
 	iface->assign = iiter_assign;
 	iface->clone = iiter_clone;
+	iface->diff = iiter_diff;
+	iface->compare = iiter_compare;
 }
 
 
