@@ -19,7 +19,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -970,6 +970,8 @@ anjuta_symbol_view_dispose (GObject * obj)
 {
 	AnjutaSymbolView *sv = ANJUTA_SYMBOL_VIEW (obj);
 	
+	g_source_remove_by_user_data (sv);
+
 	/* All file symbol refs would be freed when the hash table is distroyed */
 	sv->priv->file_symbol_model = NULL;
 	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (obj));
@@ -980,7 +982,6 @@ static void
 anjuta_symbol_view_instance_init (GObject * obj)
 {
 	AnjutaSymbolView *sv;
-	gchar *system_tags_path;
 	
 	sv = ANJUTA_SYMBOL_VIEW (obj);
 	sv->priv = g_new0 (AnjutaSymbolViewPriv, 1);
@@ -991,15 +992,6 @@ anjuta_symbol_view_instance_init (GObject * obj)
 												g_free,
 												destroy_tm_hash_value);
 	
-	system_tags_path = g_build_filename (g_get_home_dir(), ".anjuta",
-										 "system-tags.cache", NULL);
-	/* Load gloabal tags on gtk idle */
-	if (!tm_workspace_load_global_tags (system_tags_path))
-	{
-		g_idle_add((GSourceFunc) symbol_browser_prefs_create_global_tags, 
-				   ANJUTA_SYMBOL_VIEW (obj));
-	}
-
 	/* let's create symbol_view tree and other gui stuff */
 	sv_create (sv);
 }
@@ -1245,17 +1237,15 @@ void
 anjuta_symbol_view_workspace_add_file (AnjutaSymbolView * sv,
 									   const gchar * file_uri)
 {
-	const gchar *uri;
+	gchar *uri;
 	TMWorkObject *tm_file;
 	GtkTreeModel *store = NULL;
 
 	g_return_if_fail (ANJUTA_IS_SYMBOL_VIEW (sv));
 	g_return_if_fail (file_uri != NULL);
 
-	if (strncmp (file_uri, "file://", 7) == 0)
-		uri = &file_uri[7];
-	else
-		return;
+	uri = gnome_vfs_get_local_path_from_uri (file_uri);
+	if (uri == NULL) return;	/* Not a local path */
 	
 	store = g_hash_table_lookup (sv->priv->tm_files, uri);
 	if (!store)
@@ -1294,6 +1284,7 @@ anjuta_symbol_view_workspace_add_file (AnjutaSymbolView * sv,
 								 g_strdup (uri), store);
 		}
 	}
+	g_free (uri);
 	sv->priv->file_symbol_model = store;
 }
 
@@ -1301,19 +1292,18 @@ void
 anjuta_symbol_view_workspace_remove_file (AnjutaSymbolView * sv,
 										  const gchar * file_uri)
 {
-	const gchar *uri;
+	gchar *uri;
 
 	g_return_if_fail (ANJUTA_IS_SYMBOL_VIEW (sv));
 	g_return_if_fail (file_uri != NULL);
 
 	DEBUG_PRINT ("Removing Symbol URI: %s", file_uri);
-	if (strncmp (file_uri, "file://", 7) == 0)
-		uri = &file_uri[7];
-	else
-		uri = file_uri;
+	uri = gnome_vfs_get_local_path_from_uri (file_uri);
+	if (uri == NULL) return;	/* Not a local path */
 	
 	if (g_hash_table_lookup (sv->priv->tm_files, uri))
 		g_hash_table_remove (sv->priv->tm_files, uri);
+	g_free (uri);
 }
 
 
@@ -1327,7 +1317,7 @@ anjuta_symbol_view_workspace_update_file (AnjutaSymbolView * sv,
 	g_return_if_fail (new_file_uri != NULL);
 	if (old_file_uri)
 		anjuta_symbol_view_workspace_remove_file (sv, old_file_uri);
-	anjuta_symbol_view_workspace_add_file (sv, old_file_uri);
+	anjuta_symbol_view_workspace_add_file (sv, new_file_uri);
 #if 0
 	const gchar *uri;
 	TMWorkObject *tm_file;
@@ -1729,7 +1719,6 @@ sv_get_type_of_token (const gchar* ident, const gchar* klass, const TMTag* local
 				TMTag *cur_tag;
 			
 				cur_tag = (TMTag*)g_ptr_array_index (tags_array , i);
-				g_message ("found following %d array_tmp tag: %s", i, cur_tag ->name );
 				if ( strcmp (cur_tag->name, scope_tag->atts.entry.scope) == 0) {
 					scope_tag = cur_tag;
 					break;
