@@ -38,6 +38,7 @@
 #include <libanjuta/interfaces/ianjuta-file-loader.h>
 
 #include <libgnomeui/libgnomeui.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 
 #include <gtk/gtk.h>
 
@@ -779,7 +780,7 @@ on_editor_response (GtkDialog *dialog, gint response, gpointer user_data)
 		if (gtk_toggle_button_get_active (this->script_tb))
 		{
 			IAnjutaDocumentManager *docman;
-			IAnjutaDocument *editor;
+			IAnjutaDocument *doc;
 
 			/* Check that default script directory exist */
 			data = g_build_filename (g_get_home_dir(), LOCAL_ANJUTA_SCRIPT_DIRECTORY, NULL);
@@ -816,25 +817,24 @@ on_editor_response (GtkDialog *dialog, gint response, gpointer user_data)
 				return;
 			}
 
-			editor = 
+			doc =
 				ianjuta_document_manager_find_document_with_path 
 							   (docman, data, NULL);
-			if (editor == NULL)
+			if (doc == NULL)
 			{
 				IAnjutaFileLoader* loader;
 				gchar *uri;
 
 				/* Not found, load file */
 				loader = IANJUTA_FILE_LOADER (anjuta_shell_get_interface (ANJUTA_PLUGIN (this->parent->plugin)->shell, IAnjutaFileLoader, NULL));
-				uri = g_strdup_printf("file:///%s", data);
+				uri = gnome_vfs_get_uri_from_local_path(data);
 				ianjuta_file_loader_load (loader, uri, FALSE, NULL);
 				g_free (uri);
 			}
 			else
 			{
 				/* Set as current */
-				ianjuta_document_manager_set_current_document 
-					(docman, IANJUTA_DOCUMENT(editor), NULL);
+				ianjuta_document_manager_set_current_document (docman, doc, NULL);
 			}
 			g_free (data);
 		}
