@@ -8,14 +8,15 @@
   * the Free Software Foundation; either version 2 of the License, or
   * (at your option) any later version.
   * 
-  * This program is distributed in the hope that it will be useful,
+  * T
+his program is distributed in the hope that it will be useful,
   * but WITHOUT ANY WARRANTY; without even the implied warranty of
   * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   * GNU General Public License for more details.
   * 
   * You should have received a copy of the GNU General Public License
   * along with this program; if not, write to the Free Software
-  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
   */
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -35,10 +36,9 @@
 
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/resources.h>
-#include <libanjuta/plugins.h>
+#include <libanjuta/interfaces/ianjuta-preferences.h>
 
 #include "anjuta-app.h"
-// #include "help.h"
 #include "about.h"
 #include "action-callbacks.h"
 #include "anjuta.h"
@@ -82,50 +82,29 @@ on_reset_layout_activate(GtkAction *action, AnjutaApp *app)
 void
 on_set_preferences1_activate (GtkAction * action, AnjutaApp *app)
 {
-	gtk_widget_show (GTK_WIDGET (app->preferences));
-}
 
-void
-on_set_default_preferences1_activate (GtkAction * action,
-				      AnjutaApp *app)
-{
-	anjuta_preferences_reset_defaults (ANJUTA_PREFERENCES (app->preferences));
-}
-
-void
-on_customize_shortcuts_activate(GtkAction *action, AnjutaApp *app)
-{
-	GtkWidget *win, *accel_editor;
+	GtkWidget *preferences_dialog;
 	
-	accel_editor = anjuta_ui_get_accel_editor (ANJUTA_UI (app->ui));
-	win = gtk_dialog_new_with_buttons (_("Anjuta Plugins"), GTK_WINDOW (app),
-									   GTK_DIALOG_DESTROY_WITH_PARENT,
-									   GTK_STOCK_CLOSE, GTK_STOCK_CANCEL, NULL);
-	gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG(win)->vbox), accel_editor);
-	gtk_window_set_default_size (GTK_WINDOW (win), 500, 400);
-	gtk_dialog_run (GTK_DIALOG (win));
-	gtk_widget_destroy (win);
-}
-
-void
-on_show_plugins_activate (GtkAction *action, AnjutaApp *app)
-{
-	GtkWidget *win, *plg;
+	preferences_dialog = anjuta_preferences_get_dialog (app->preferences);
 	
-	plg = anjuta_plugins_get_installed_dialog (ANJUTA_SHELL (app));
-	win = gtk_dialog_new_with_buttons (_("Anjuta Plugins"), GTK_WINDOW (app),
-									   GTK_DIALOG_DESTROY_WITH_PARENT,
-									   GTK_STOCK_CLOSE, GTK_STOCK_CANCEL, NULL);
-	gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG(win)->vbox), plg);
-	gtk_window_set_default_size (GTK_WINDOW(win), 500, 550);
-	gtk_dialog_run (GTK_DIALOG (win));
-	gtk_widget_destroy (win);
+	/* Install main application preferences */
+	anjuta_app_install_preferences (app);
+	
+	g_signal_connect_swapped (G_OBJECT (preferences_dialog),
+					  		  "response",
+					  		  G_CALLBACK (gtk_widget_destroy),
+					  		  preferences_dialog); 
+	
+	gtk_window_set_transient_for (GTK_WINDOW (preferences_dialog),
+								  GTK_WINDOW (app));
+								  
+	gtk_widget_show (preferences_dialog);
 }
 
 static void
-help_activate (const gchar *item)
+help_activate (const gchar *doc_id, const gchar *item)
 {
-	if (gnome_help_display (item, NULL, NULL) == FALSE)
+	if (gnome_help_display_with_doc_id (NULL, doc_id, item, NULL, NULL) == FALSE)
 	{
 	  anjuta_util_dialog_error (NULL, _("Unable to display help. Please make sure Anjuta documentation package is install. It can be downloaded from http://anjuta.org"));	
 	}
@@ -134,25 +113,25 @@ help_activate (const gchar *item)
 void
 on_help_manual_activate (GtkAction *action, gpointer data)
 {
-	help_activate ("anjuta-manual.xml");
+	help_activate ("anjuta-manual", "anjuta-manual.xml");
 }
 
 void
 on_help_tutorial_activate (GtkAction *action, gpointer data)
 {
-	help_activate ("anjuta-tutorial.xml");
+	help_activate ("anjuta-tutorial", "anjuta-tutorial.xml");
 }
 
 void
 on_help_advanced_tutorial_activate (GtkAction *action, gpointer data)
 {
-	help_activate ("anjuta-advanced-tutorial.xml");
+	help_activate ("anjuta-advanced-tutorial", "anjuta-advanced-tutorial.xml");
 }
 
 void
 on_help_faqs_activate (GtkAction *action, gpointer data)
 {
-	help_activate ("anjuta-faqs.xml");
+	help_activate ("anjuta-faqs", "anjuta-faqs.xml");
 }
 
 void
