@@ -13,7 +13,7 @@
  * for more details.
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc., 59 
- * Temple Place, Suite 330, Boston, MA  02111-1307  USA 
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -33,6 +33,7 @@
 
 #include <gdl/gdl-dock.h>
 #include <gdl/gdl-dock-bar.h>
+#include <gdl/gdl-switcher.h>
 
 #include <bonobo/bonobo-dock-item.h>
 
@@ -49,7 +50,7 @@
 
 #define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta.ui"
 #define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta.glade"
-#define ICON_FILE "preferences-general.png"
+#define ICON_FILE "anjuta-preferences-general-48.png"
 
 #define DOCK_PH_LEFT    "ph_left"
 #define DOCK_PH_RIGHT   "ph_right"
@@ -66,6 +67,36 @@ static void anjuta_app_layout_save (AnjutaApp *app,
 static gpointer parent_class = NULL;
 static GList* toolbars = NULL;
 
+static void
+on_gdl_style_changed (GConfClient* client, guint id, GConfEntry* entry,
+					  gpointer user_data)
+{
+	AnjutaApp* app = ANJUTA_APP (user_data);
+	GdlSwitcherStyle style = GDL_SWITCHER_STYLE_BOTH;
+	
+	gchar* pr_style = anjuta_preferences_get (app->preferences, "anjuta.gdl.style");
+
+	if (pr_style)
+	{
+		if (strcasecmp (pr_style, "Text") == 0)
+			style = GDL_SWITCHER_STYLE_TEXT;
+		else if (strcasecmp (pr_style, "Icon") == 0)
+			style = GDL_SWITCHER_STYLE_ICON;
+		else if (strcasecmp (pr_style, "Both") == 0)
+			style = GDL_SWITCHER_STYLE_BOTH;
+		else if (strcasecmp (pr_style, "Toolbar") == 0)
+			style = GDL_SWITCHER_STYLE_TOOLBAR;
+		else if (strcasecmp (pr_style, "Tabs") == 0)
+			style = GDL_SWITCHER_STYLE_TABS;
+		
+		DEBUG_PRINT ("Switcher style: %s", pr_style);
+		
+		g_free (pr_style);
+	}
+	g_object_set (G_OBJECT(app->layout_manager->master), "switcher-style",
+					  style, NULL);
+}
+
 static void
 on_toggle_widget_view (GtkCheckMenuItem *menuitem, GtkWidget *dockitem)
 {
@@ -175,7 +206,7 @@ on_toolbar_view_toggled (GtkCheckMenuItem *menuitem, GtkWidget *widget)
 									   									   
 			dock_item = gnome_app_get_dock_item_by_name (GNOME_APP (app),
 														 unique_name);
-			g_object_set_data (G_OBJECT(dock_item), "unique_name", unique_name);
+			g_object_set_data_full (G_OBJECT(dock_item), "unique_name", unique_name, g_free);
 			g_object_set_data (G_OBJECT(widget), "dock_item", dock_item);
 			count++;
 		}
@@ -501,7 +532,6 @@ anjuta_app_finalize (GObject *widget)
 static void
 anjuta_app_instance_init (AnjutaApp *app)
 {
-	GladeXML* gxml;
 	gint merge_id;
 	GtkWidget *toolbar_menu, *about_menu;
 	GtkWidget *view_menu, *hbox;
@@ -551,12 +581,6 @@ anjuta_app_instance_init (AnjutaApp *app)
 	g_object_ref (G_OBJECT (app->status));
 	g_object_add_weak_pointer (G_OBJECT (app->status), (gpointer)&app->status);
 	
-	/* Preferences */
-	app->preferences = ANJUTA_PREFERENCES (anjuta_preferences_new ());
-	g_object_add_weak_pointer (G_OBJECT (app->preferences),
-							   (gpointer)&app->preferences);
-	anjuta_status_add_widget (ANJUTA_STATUS (app->status),
-							  GTK_WIDGET (app->preferences));
 	/* UI engine */
 	app->ui = anjuta_ui_new ();
 	
@@ -578,6 +602,16 @@ anjuta_app_instance_init (AnjutaApp *app)
 	app->profile_manager = anjuta_profile_manager_new (app->plugin_manager);
 	g_list_free (plugins_dirs);
 	
+	/* Preferences */
+	app->preferences = anjuta_preferences_new (app->plugin_manager);
+	g_object_add_weak_pointer (G_OBJECT (app->preferences),
+							   (gpointer)&app->preferences);
+	
+	anjuta_preferences_notify_add (app->preferences, "anjuta.gdl.style",
+								   on_gdl_style_changed, app, NULL);
+	
+	on_gdl_style_changed (NULL, 0, NULL, app);
+	
 	/* Register actions */
 	anjuta_ui_add_action_group_entries (app->ui, "ActionGroupFile", _("File"),
 										menu_entries_file,
@@ -592,15 +626,10 @@ anjuta_app_instance_init (AnjutaApp *app)
 										G_N_ELEMENTS (menu_entries_view),
 										GETTEXT_PACKAGE, TRUE, app);
 	anjuta_ui_add_toggle_action_group_entries (app->ui, "ActionGroupToggleView",
-										_("Toggle View"),
+										_("View"),
 										menu_entries_toggle_view,
 										G_N_ELEMENTS (menu_entries_toggle_view),
 										GETTEXT_PACKAGE, TRUE, app);
-	anjuta_ui_add_action_group_entries (app->ui, "ActionGroupSettings",
-										_("Settings"),
-										menu_entries_settings,
-										G_N_ELEMENTS (menu_entries_settings),
-										GETTEXT_PACKAGE, TRUE, app);
 	anjuta_ui_add_action_group_entries (app->ui, "ActionGroupHelp", _("Help"),
 										menu_entries_help,
 										G_N_ELEMENTS (menu_entries_help),
@@ -637,16 +666,7 @@ anjuta_app_instance_init (AnjutaApp *app)
 								   "/MenuMain/PlaceHolderHelpMenus/MenuHelp/"
 								   "PlaceHolderHelpAbout/AboutPlugins");
 	about_create_plugins_submenu (ANJUTA_SHELL (app), about_menu);
-							  
-	gtk_window_set_transient_for (GTK_WINDOW (app->preferences),
-								  GTK_WINDOW (app));
-	
-	/* Create preferences page */
-	gxml = glade_xml_new (GLADE_FILE, "anjuta_preferences_window", NULL);
-	anjuta_preferences_add_page (app->preferences, gxml,
-								 "General", _("General"), ICON_FILE);
-	g_object_unref (gxml);
-	
+							
 	/* Connect to session */
 	g_signal_connect (G_OBJECT (app), "save_session",
 					  G_CALLBACK (on_session_save), app);
@@ -785,6 +805,35 @@ anjuta_app_layout_reset (AnjutaApp *app)
 	anjuta_app_layout_load (app, NULL, NULL);
 }
 
+void 
+anjuta_app_install_preferences (AnjutaApp *app)
+{
+	GladeXML *gxml;	
+	GtkWidget *notebook, *shortcuts, *plugins, *remember_plugins;
+	
+	/* Create preferences page */
+	gxml = glade_xml_new (GLADE_FILE, "anjuta_preferences_window", NULL);
+	anjuta_preferences_add_page (app->preferences, gxml,
+								 "General", _("General"), ICON_FILE);
+	notebook = 	glade_xml_get_widget (gxml, "General");
+	shortcuts = anjuta_ui_get_accel_editor (ANJUTA_UI (app->ui));
+	plugins = anjuta_plugin_manager_get_plugins_page (app->plugin_manager);
+	remember_plugins = anjuta_plugin_manager_get_remembered_plugins_page (app->plugin_manager);
+	
+	gtk_widget_show (shortcuts);
+	gtk_widget_show (plugins);
+	gtk_widget_show (remember_plugins);
+	
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), plugins,
+							  gtk_label_new (_("Installed plugins")));
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), remember_plugins,
+							  gtk_label_new (_("Preferred plugins")));
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), shortcuts,
+							  gtk_label_new (_("Shortcuts")));
+	
+	g_object_unref (gxml);
+}
+
 /* AnjutaShell Implementation */
 
 static void
@@ -968,12 +1017,13 @@ on_widget_removed_from_hash (gpointer widget)
 }
 
 static void 
-anjuta_app_add_widget (AnjutaShell *shell, 
+anjuta_app_add_widget_full (AnjutaShell *shell, 
 					   GtkWidget *widget,
 					   const char *name,
 					   const char *title,
 					   const char *stock_id,
 					   AnjutaShellPlacement placement,
+					   gboolean locked,
 					   GError **error)
 {
 	AnjutaApp *app;
@@ -1008,6 +1058,16 @@ anjuta_app_add_widget (AnjutaShell *shell,
 	else
 		item = gdl_dock_item_new_with_stock (name, title, stock_id,
 											 GDL_DOCK_ITEM_BEH_NORMAL);
+	if (locked)
+	{
+		guint flags = 0;
+		flags |= GDL_DOCK_ITEM_BEH_NEVER_FLOATING;
+		flags |= GDL_DOCK_ITEM_BEH_CANT_CLOSE;
+		flags |= GDL_DOCK_ITEM_BEH_CANT_ICONIFY;
+		flags |= GDL_DOCK_ITEM_BEH_NO_GRIP;
+		g_object_set(G_OBJECT(item), "behavior", flags, NULL);
+	}
+	
 	gtk_container_add (GTK_CONTAINER (item), widget);
     gdl_dock_add_item (GDL_DOCK (app->dock),
                        GDL_DOCK_ITEM (item), placement);
@@ -1018,6 +1078,10 @@ anjuta_app_add_widget (AnjutaShell *shell,
 	gtk_widget_show (GTK_WIDGET (menuitem));
 	gtk_check_menu_item_set_active (menuitem, TRUE);
 	gtk_menu_append (GTK_MENU (app->view_menu), GTK_WIDGET (menuitem));
+
+	if (locked)
+		g_object_set( G_OBJECT(menuitem), "visible", FALSE, NULL);
+
 	
 	g_object_set_data (G_OBJECT (widget), "app-object", app);
 	g_object_set_data (G_OBJECT (widget), "menuitem", menuitem);
@@ -1146,7 +1210,7 @@ anjuta_app_get_profile_manager (AnjutaShell *shell, GError **error)
 static void
 anjuta_shell_iface_init (AnjutaShellIface *iface)
 {
-	iface->add_widget = anjuta_app_add_widget;
+	iface->add_widget_full = anjuta_app_add_widget_full;
 	iface->remove_widget = anjuta_app_remove_widget;
 	iface->present_widget = anjuta_app_present_widget;
 	iface->add_value = anjuta_app_add_value;
